# -*- coding: utf-8 -*-
"""
Created on Sun Aug 16 14:50:37 2020

@author: kuzn137
"""

from setuptools import setup

setup(name = 'heteroscedasticity_tests',
      long_description=""" Tests for heteroscedasticity, Park and Glejser""",
      long_description_content_type='text/markdown',
      version = 1.0,
      description = 'Tests for heteroscedasticity, Park and Glejser',
      packages = ['heteroscedasticity_tests'],
      author = 'Inga Kuznetsova',
      author_email = 'kuzn137@gmail.com'
      )